.. DANGER:: 

      Please note that this version of CubeViz is **no longer being actively supported
      or maintained**. The functionality of CubeViz is now available and being actively
      developed as part of `Jdaviz <https://github.com/spacetelescope/jdaviz>`_.

Keyboard Shortcuts
------------------

There are some cubeviz-specific keyboard shortcuts available:

.. list-table:: Keyboard Shortcuts
   :header-rows: 1

   * - Shortcut
     - Purpose
   * - A
     - Move slider index one to the left
   * - D
     - Move slider index one to the right
   * - F
     - Lock coordinates in the bottom right of the viewer window
   * - P
     - Copy coordinates to clipboard so user can paste them elsewhere
   * - 1
     - Popup the Wavelength dialog in order to change the units or redshift.




